package net.pricefx.common.api;

/*
 * Enum for email notifications that can be disabled in config ui.
 */

import java.util.stream.Collectors;
import java.util.stream.Stream;

public enum WorkflowTemplateType {

    APPROVAL_REQUIRED("approvalRequired", true),
    APPROVAL_REQUIRED_FORM("approvalRequiredForm", true, false),
    STEP_APPROVED("stepApproved", true),
    STEP_DENIED("stepDenied", true),
    WORKFLOW_APPROVED("workflowApproved", false),
    APPROVAL_DELEGATED("approvalDelegated", true),
    CREATION_WORKFLOW_STEP_ASSIGNED("creationWorkflowStepAssigned", true),
    CREATION_WORKFLOW_FINISHED("creationWorkflowFinished", true),
    QUOTE_CONVERTED_TO_DEAL("quoteConverted", true),
    PENDING_WORKFLOWS_SUMMARY("pendingWorkflowsSummary", true);

    private String typeName;
    private boolean isEmail;
    private boolean isEnabledByDefault;

    WorkflowTemplateType(String typeName, boolean isEnabledByDefault) {
        this(typeName, isEnabledByDefault, true);
    }

    WorkflowTemplateType(String typeName, boolean isEnabledByDefault, boolean isEmail) {
        this.typeName = typeName;
        this.isEnabledByDefault = isEnabledByDefault;
        this.isEmail = isEmail;
    }

    public String getTypeName() {
        return typeName;
    }

    public static WorkflowTemplateType[] allEmailTypes() {
        return Stream.of(WorkflowTemplateType.values()).filter(WorkflowTemplateType::isEmail).toArray(WorkflowTemplateType[]::new);
    }

    public boolean isEnabledByDefault() {
        return isEnabledByDefault;
    }

    public boolean isEmail() { return isEmail; }
}
